@@ -15,7 +15,6 @@ XCOMM Define these now or down further below, see below for explaination.
 XCOMM  #define CPPCompiler
 XCOMM  #define XpmLibrary
 XCOMM  #define XmLibrary
-XCOMM  #define XawLibrary
 XCOMM  #define GLLibrary
 XCOMM  #define DtSaverLibrary
 XCOMM  #define DPMSLibrary
@@ -115,28 +114,6 @@ XCOMM  EDITRESLIB = -lXmu
 
 XCOMM   *** END XM CONFIG SECTION ***
 
-XCOMM   *** BEGIN XAW CONFIG SECTION ***
-
-XCOMM Only options.c and xalock.c uses Athena.
-XCOMM If your system has libsx, libXaw, and libXmu,
-XCOMM remove the 'XCOMM  ' from the next line.
-XCOMM  #define XawLibrary
-
-#ifdef XawLibrary
-XCOMM If its not with your X11 stuff you should set the following
-XCOMM  ATHENAHOME = /usr/local
-
-XCOMM Below is a guess.
-XCOMM  XAWINC = -I$(ATHENAHOME)/include
-
-XCOMM Below is a guess.
-XCOMM  XAWLIB = -L$(ATHENAHOME)/lib -lsx -lXaw -lXmu
-XAWLIB = -lsx -lXaw -lXmu
-
-#endif
-
-XCOMM   *** END XAW CONFIG SECTION ***
-
 XCOMM   *** BEGIN MESAGL AND OPENGL CONFIG SECTION ***
 
 XCOMM escher, gears, morph3d, pipes, superquadrics, sproingies modes use this.
@@ -302,6 +279,15 @@ CHECKDEF = -DDEBUG
 
 XCOMM      *** END DEBUG CHECK SECTION ***
 
+XCOMM      *** BEGIN INTERACTIVE CHECK SECTION ***
+
+#define DisableInteractive
+
+#ifdef DisableInteractive
+XCOMM Can disable interactive modes for production environments
+INTERACTIVEDEF = -DDISABLE_INTERACTIVE
+#endif
+
 XCOMM      *** BEGIN UNSTABLE CHECK SECTION ***
 
 XCOMM #define Unstable
@@ -493,7 +479,9 @@ XCOMM -DUSE_BUTTON_LOGOUT=10    Enable logout button and set appear time (min)
 XCOMM -DDEF_BUTTON_LOGOUT=\"5\" Set default logout button (minutes)
 XCOMM -DUSE_BOMB                Enable automatic logout mode (does not come up
 XCOMM                           in random mode)
-XCOMM -DUSE_UNSTABLE            Enable unstable bubble3d GL mode
+XCOMM -DDISABLE_INTERACTIVE     Disable interactive modes (useful for production
+XCOMM                           enviroments)
+XCOMM -DUSE_UNSTABLE            Enable unstable (alpha) modes
 XCOMM -DCLOSEDOWN_LOGOUT        Use with USE_AUTO_LOGOUT, USE_BUTTON_LOGOUT,
 XCOMM                           USE_BOMB if using xdm
 XCOMM -DSESSION_LOGOUT          Alternate of above
@@ -502,6 +490,7 @@ XCOMM -DSTAFF_NETGROUP=\"/etc/xlock.netgroup\"  Netgroup that is exempt
 
 XCOMM May have to combine in one long line if "+=" does not work
 OPTDEF = -DUSE_VROOT -DALWAYS_ALLOW_ROOT -DUSE_BOMB
+XCOMM  OPTDEF += -DDISABLE_INTERACTIVE
 XCOMM  OPTDEF += -DUSE_UNSTABLE
 XCOMM  OPTDEF += -DUSE_SYSLOG -DSYSLOG_FACILITY=LOG_AUTH
 XCOMM  OPTDEF += -DSYSLOG_WARNING=LOG_WARNING
@@ -521,8 +510,8 @@ XCOMM  OPTDEF += -DSTAFF_NETGROUP=\"/etc/xlock.netgroup\"
 
 DEFINES = -DDEF_FILESEARCHPATH=\"$(LIBDIR)/%T/%N%S\" \
 $(SYSTEMDEF) $(EDITRESDEF) $(SLEEPDEF) $(OPTDEF) $(RANDDEF) \
-$(MODULEDEF) $(CHECKDEF) $(UNSTABLEDEF) $(PASSWDDEF) $(XMINC) $(XAWINC) \
-$(CPPDEF) $(XPMDEF) $(GLDEF) $(DTSAVERDEF) $(DPMSDEF) \
+$(MODULEDEF) $(CHECKDEF) $(INTERACTIVEDEF) $(UNSTABLEDEF) $(PASSWDDEF) \
+$(XMINC) $(XAWINC) $(CPPDEF) $(XPMDEF) $(GLDEF) $(DTSAVERDEF) $(DPMSDEF) \
 $(SOUNDDEF) $(PASSWDINC) $(XPMINC) $(GLINC) $(DTSAVERINC) $(DPMSINC) \
 $(SOUNDINC) $(XLOCKINC)
 
