@@ -50,16 +50,16 @@ static Bool boil;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-boil", ".bubble.boil", XrmoptionNoArg, (caddr_t) "on"},
-	{"+boil", ".bubble.boil", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-boil", (char *) ".bubble.boil", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+boil", (char *) ".bubble.boil", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & boil, "boil", "Boil", DEF_BOIL, t_Bool}
+	{(caddr_t *) & boil, (char *) "boil", (char *) "Boil", (char *) DEF_BOIL, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+boil", "turn on/off boil"}
+	{(char *) "-/+boil", (char *) "turn on/off boil"}
 };
 
 ModeSpecOpt bubble_opts =
