@@ -60,20 +60,20 @@ static Bool liss;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-grow", ".drift.grow", XrmoptionNoArg, (caddr_t) "on"},
-	{"+grow", ".drift.grow", XrmoptionNoArg, (caddr_t) "off"},
-	{"-liss", ".drift.trail", XrmoptionNoArg, (caddr_t) "on"},
-	{"+liss", ".drift.trail", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-grow", (char *) ".drift.grow", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+grow", (char *) ".drift.grow", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-liss", (char *) ".drift.trail", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+liss", (char *) ".drift.trail", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & grow, "grow", "Grow", DEF_GROW, t_Bool},
-	{(caddr_t *) & liss, "liss", "Liss", DEF_LISS, t_Bool}
+	{(caddr_t *) & grow, (char *) "grow", (char *) "Grow", (char *) DEF_GROW, t_Bool},
+	{(caddr_t *) & liss, (char *) "liss", (char *) "Liss", (char *) DEF_LISS, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+grow", "turn on/off growing fractals, else they are animated"},
-	{"-/+liss", "turn on/off using lissojous figures to get points"}
+	{(char *) "-/+grow", (char *) "turn on/off growing fractals, else they are animated"},
+	{(char *) "-/+liss", (char *) "turn on/off using lissojous figures to get points"}
 };
 
 ModeSpecOpt drift_opts =
