@@ -119,12 +119,15 @@ ModStruct   cage_description =
 #define Pi                         M_PI
 #endif
 
+#define ObjWoodPlank    0
+#define MaxObj          1
+
 /*************************************************************************/
 
 typedef struct {
 	GLint       WindH, WindW;
 	GLfloat     step;
-	int         AreObjectsDefined[1];
+	int         AreObjectsDefined[MaxObj];
 	GLXContext *glx_context;
 } cagestruct;
 
@@ -151,8 +154,6 @@ static float MaterialWhite[] =
 static cagestruct *cage = NULL;
 static GLuint objects;
 
-#define ObjWoodPlank    0
-
 #define PlankWidth      3.0
 #define PlankHeight     0.35
 #define PlankThickness  0.15
@@ -375,7 +376,7 @@ init_cage(ModeInfo * mi)
 		reshape(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 		glDrawBuffer(GL_BACK);
 		if (!glIsList(objects))
-			objects = glGenLists(1);
+			objects = glGenLists(MaxObj);
 		pinit();
 	} else {
 		MI_CLEARWINDOW(mi);
