@@ -104,20 +104,20 @@ static int  noants;
 
 static XrmOptionDescRec opts[] =
 {
-  {"-solidmoebius", ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "on"},
- {"+solidmoebius", ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "off"},
-	{"-noants", ".moebius.noants", XrmoptionNoArg, (caddr_t) "on"},
-	{"+noants", ".moebius.noants", XrmoptionNoArg, (caddr_t) "off"}
+  {(char *) "-solidmoebius", (char *) ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "on"},
+ {(char *) "+solidmoebius", (char *) ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-noants", (char *) ".moebius.noants", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+noants", (char *) ".moebius.noants", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & solidmoebius, "solidmoebius", "Solidmoebius", DEF_SOLIDMOEBIUS, t_Bool},
-	{(caddr_t *) & noants, "noants", "Noants", DEF_NOANTS, t_Bool}
+	{(caddr_t *) & solidmoebius, (char *) "solidmoebius", (char *) "Solidmoebius", (char *) DEF_SOLIDMOEBIUS, t_Bool},
+	{(caddr_t *) & noants, (char *) "noants", (char *) "Noants", (char *) DEF_NOANTS, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+solidmoebius", "select between a SOLID or a NET Moebius Strip"},
-	{"-/+noants", "turn on/off walking ants"}
+	{(char *) "-/+solidmoebius", (char *) "select between a SOLID or a NET Moebius Strip"},
+	{(char *) "-/+noants", (char *) "turn on/off walking ants"}
 };
 
 ModeSpecOpt moebius_opts =
@@ -141,13 +141,17 @@ ModStruct   moebius_description =
 #define Pi                         M_PI
 #endif
 
+#define ObjMoebiusStrip 0
+#define ObjAntBody      1
+#define MaxObj          2
+
 /*************************************************************************/
 
 typedef struct {
 	GLint       WindH, WindW;
 	GLfloat     step;
 	GLfloat     ant_position;
-	int         AreObjectsDefined[2];
+	int         AreObjectsDefined[MaxObj];
 	GLXContext *glx_context;
 } moebiusstruct;
 
@@ -192,12 +196,7 @@ static float MaterialGray8[] =
 {0.8, 0.8, 0.8, 1.0};
 
 static moebiusstruct *moebius = NULL;
-static GLuint objects;
-
-#define NUM_SCENES      2
-
-#define ObjMoebiusStrip 0
-#define ObjAntBody      1
+static GLuint objects = 0;
 
 static void
 mySphere(float radius)
@@ -632,7 +631,7 @@ init_moebius(ModeInfo * mi)
 		reshape(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 		glDrawBuffer(GL_BACK);
 		if (!glIsList(objects))
-			objects = glGenLists(3);
+			objects = glGenLists(MaxObj);
 		pinit();
 	} else {
 		MI_CLEARWINDOW(mi);
