@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 4 -*- */
-/* rubik --- Shows a auto-solving Rubik's cube */
+/* rubik --- Shows an auto-solving Rubik's cube */
 
 #if !defined( lint ) && !defined( SABER )
 static const char sccsid[] = "@(#)rubik.c	4.14 99/04/27 xlockmore";
@@ -67,39 +67,31 @@ static const char sccsid[] = "@(#)rubik.c	4.14 99/04/27 xlockmore";
  * Color labels mapping:
  * =====================
  *
- *                       +------------+
- *                       |0-->        |
- *                       ||           |
- *                       |v           |
- *                       |   TOP(0)   |
- *                       |            |
- *                       |            |
- *                       |           8|
- *           +-----------+------------+-----------+
- *           |0-->       |0-->        |0-->       |
- *           ||          ||           ||          |
- *           |v          |v           |v          |
- *           |  LEFT(1)  |  FRONT(2)  |  RIGHT(3) |
- *           |           |            |           |
- *           |           |            |           |
- *           |          8|           8|          8|
- *           +-----------+------------+-----------+
- *                       |0-->        |
- *                       ||           |
- *                       |v           |
- *                       |  BOTTOM(4) |
- *                       |            |
- *                       |            |
- *                       |           8|         +---+---+---+
- *                       +------------+         |   |   |   |
- *                       |0-->        |         | 0 | 1 | 2 |
- *                       ||           |         |---+---+---+
- *                       |v           |         |  xxxxx(N) |
- *                       |   BACK(5)  |         | 3 | 4 | 5 |
- *                       |            |         +---+---+---+
- *                       |            |         |   |   |   |
- *                       |           8|         | 6 | 7 | 8 |
- *                       +------------+         +---+---+---+
+ *             +-----------+
+ *             |0-->       |
+ *             ||          |
+ *             |v  TOP(0)  |
+ *             |           |
+ *             |          8|
+ * +-----------+-----------+-----------+
+ * |0-->       |0-->       |0-->       |
+ * ||          ||          ||          |
+ * |v  LEFT(1) |v FRONT(2) |v RIGHT(3) |
+ * |           |           |           |
+ * |          8|          8|          8|
+ * +-----------+-----------+-----------+
+ *             |0-->       |
+ *             ||          |
+ *             |v BOTTOM(4)|
+ *             |           |
+ *             |          8|
+ *             +-----------+             +---+---+---+
+ *             |0-->       |             | 0 | 1 | 2 |
+ *             ||          |             |--xxxxx(N)-+
+ *             |v  BACK(5) |             | 3 | 4 | 5 |
+ *             |           |             +---+---+---+
+ *             |          8|             | 6 | 7 | 8 |
+ *             +-----------+             +---+---+---+
  *
  *  Map to 3d
  *  FRONT  => X, Y
@@ -151,27 +143,27 @@ static Bool hideshuffling;
 
 static XrmOptionDescRec opts[] =
 {
-        {"-sizex", ".rubik.sizex", XrmoptionSepArg, (caddr_t) NULL},
-        {"-sizey", ".rubik.sizey", XrmoptionSepArg, (caddr_t) NULL},
-        {"-sizez", ".rubik.sizez", XrmoptionSepArg, (caddr_t) NULL},
-	{"-hideshuffling", ".rubik.hideshuffling", XrmoptionNoArg, (caddr_t) "on"},
-	{"+hideshuffling", ".rubik.hideshuffling", XrmoptionNoArg, (caddr_t) "off"}
+        {(char *) "-sizex", (char *) ".rubik.sizex", XrmoptionSepArg, (caddr_t) NULL},
+        {(char *) "-sizey", (char *) ".rubik.sizey", XrmoptionSepArg, (caddr_t) NULL},
+        {(char *) "-sizez", (char *) ".rubik.sizez", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-hideshuffling", (char *) ".rubik.hideshuffling", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+hideshuffling", (char *) ".rubik.hideshuffling", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & sizex, "sizex", "SizeX", DEF_SIZEX, t_Int},
-	{(caddr_t *) & sizey, "sizey", "SizeY", DEF_SIZEY, t_Int},
-	{(caddr_t *) & sizez, "sizez", "SizeZ", DEF_SIZEZ, t_Int},
-	{(caddr_t *) & hideshuffling, "hideshuffling", "Hideshuffling", DEF_HIDESHUFFLING, t_Bool}
+	{(caddr_t *) & sizex, (char *) "sizex", (char *) "SizeX", (char *) DEF_SIZEX, t_Int},
+	{(caddr_t *) & sizey, (char *) "sizey", (char *) "SizeY", (char *) DEF_SIZEY, t_Int},
+	{(caddr_t *) & sizez, (char *) "sizez", (char *) "SizeZ", (char *) DEF_SIZEZ, t_Int},
+	{(caddr_t *) & hideshuffling, (char *) "hideshuffling", (char *) "Hideshuffling", (char *) DEF_HIDESHUFFLING, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-sizex num", "number of cubies along x axis (overrides size)"},
-	{"-sizey num", "number of cubies along y axis (overrides size)"},
-	{"-sizez num", "number of cubies along z axis (overrides size)"},
-	{"-/+hideshuffling", "turn on/off hidden shuffle phase"}
+	{(char *) "-sizex num", (char *) "number of cubies along x axis (overrides size)"},
+	{(char *) "-sizey num", (char *) "number of cubies along y axis (overrides size)"},
+	{(char *) "-sizez num", (char *) "number of cubies along z axis (overrides size)"},
+	{(char *) "-/+hideshuffling", (char *) "turn on/off hidden shuffle phase"}
 };
 
 ModeSpecOpt rubik_opts =
@@ -248,6 +240,14 @@ ModStruct   rubik_description =
 #define REVY(a) (MAXSIZEY - a - 1)
 #define REVZ(a) (MAXSIZEZ - a - 1)
 
+#define CUBELEN 0.50
+#define CUBEROUND (CUBELEN-0.05)
+#define STICKERLONG (CUBEROUND-0.05)
+#define STICKERSHORT (STICKERLONG-0.05)
+#define STICKERDEPTH (CUBELEN+0.01)
+
+#define ObjCubit        0
+#define MaxObj          1
 typedef struct _RubikLoc {
 	int         face;
 	int         rotation;	/* Not used yet */
@@ -383,7 +383,7 @@ typedef struct {
 	GLfloat     rotatestep;
 	GLfloat     PX, PY, VX, VY;
 	GLXContext *glx_context;
-	int         AreObjectsDefined[1];
+	int         AreObjectsDefined[MaxObj];
 } rubikstruct;
 
 static float front_shininess[] =
@@ -439,7 +439,6 @@ static float MaterialGray7[] =
 static rubikstruct *rubik = NULL;
 static GLuint objects = 0;
 
-#define ObjCubit        0
 
 static void
 pickcolor(int C, int mono)
@@ -515,16 +514,16 @@ checkFaceSquare(rubikstruct * rp, int face)
 	faceSizes(rp, face, &sizeOfRow, &sizeOfColumn);
 	return (sizeOfRow == sizeOfColumn);
 	/* Cubes can be made square with a 4x2 face where 90 degree turns
-         * should be permitted but that is kind of complicated for me.
-         * This can be done in 2 ways where the side of the cubies are
-         * the same size and one where one side (the side with half the
-         * number of cubies) is twice the size of the other.  The first is
-         * complicated because faces of cubies can go under other faces.
-         * The second way is similar to "banded cubes" where scotch tape
-         * restricts the moves of some cubes.  Here you have to keep track
-         * of the restrictions and show banded cubies graphically as one
+	 * should be permitted but that is kind of complicated for me.
+	 * This can be done in 2 ways where the side of the cubies are
+	 * the same size and one where one side (the side with half the
+	 * number of cubies) is twice the size of the other.  The first is
+	 * complicated because faces of cubies can go under other faces.
+	 * The second way is similar to "banded cubes" where scotch tape
+	 * restricts the moves of some cubes.  Here you have to keep track
+	 * of the restrictions and show banded cubies graphically as one
          * cube.
-         */
+	 */
 }
 
 static int
@@ -546,141 +545,141 @@ sizeRow(rubikstruct * rp, int face)
 }
 
 static void
-draw_cubit(ModeInfo * mi,
-	   int back, int front, int left, int right, int bottom, int top)
+draw_stickerless_cubit(rubikstruct *rp)
 {
-	rubikstruct *rp = &rubik[MI_SCREEN(mi)];
-	int         mono = MI_IS_MONO(mi);
-
 	if (!rp->AreObjectsDefined[ObjCubit]) {
 		glNewList(objects + ObjCubit, GL_COMPILE_AND_EXECUTE);
 		glBegin(GL_QUADS);
 		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
+		/* Put sticker here */
 		glNormal3f(0.00, 0.00, 1.00);
-		glVertex3f(-0.45, -0.45, 0.50);
-		glVertex3f(0.45, -0.45, 0.50);
-		glVertex3f(0.45, 0.45, 0.50);
-		glVertex3f(-0.45, 0.45, 0.50);
+		glVertex3f(-CUBEROUND, -CUBEROUND, CUBELEN);
+		glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
+		glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
 		glNormal3f(0.00, 0.00, -1.00);
-		glVertex3f(-0.45, 0.45, -0.50);
-		glVertex3f(0.45, 0.45, -0.50);
-		glVertex3f(0.45, -0.45, -0.50);
-		glVertex3f(-0.45, -0.45, -0.50);
+		glVertex3f(-CUBEROUND, CUBEROUND, -CUBELEN);
+		glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
+		glVertex3f(CUBEROUND, -CUBEROUND, -CUBELEN);
+		glVertex3f(-CUBEROUND, -CUBEROUND, -CUBELEN);
 		glNormal3f(-1.00, 0.00, 0.00);
-		glVertex3f(-0.50, -0.45, 0.45);
-		glVertex3f(-0.50, 0.45, 0.45);
-		glVertex3f(-0.50, 0.45, -0.45);
-		glVertex3f(-0.50, -0.45, -0.45);
+		glVertex3f(-CUBELEN, -CUBEROUND, CUBEROUND);
+		glVertex3f(-CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(-CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(-CUBELEN, -CUBEROUND, -CUBEROUND);
 		glNormal3f(1.00, 0.00, 0.00);
-		glVertex3f(0.50, -0.45, -0.45);
-		glVertex3f(0.50, 0.45, -0.45);
-		glVertex3f(0.50, 0.45, 0.45);
-		glVertex3f(0.50, -0.45, 0.45);
+		glVertex3f(CUBELEN, -CUBEROUND, -CUBEROUND);
+		glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
 		glNormal3f(0.00, -1.00, 0.00);
-		glVertex3f(0.45, -0.50, -0.45);
-		glVertex3f(0.45, -0.50, 0.45);
-		glVertex3f(-0.45, -0.50, 0.45);
-		glVertex3f(-0.45, -0.50, -0.45);
+		glVertex3f(CUBEROUND, -CUBELEN, -CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(-CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(-CUBEROUND, -CUBELEN, -CUBEROUND);
 		glNormal3f(0.00, 1.00, 0.00);
-		glVertex3f(-0.45, 0.50, -0.45);
-		glVertex3f(-0.45, 0.50, 0.45);
-		glVertex3f(0.45, 0.50, 0.45);
-		glVertex3f(0.45, 0.50, -0.45);
+		glVertex3f(-CUBEROUND, CUBELEN, -CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
+		glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
+		glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
+
+		/* Edges of cubit */
 		glNormal3f(-1.00, -1.00, 0.00);
-		glVertex3f(-0.45, -0.50, -0.45);
-		glVertex3f(-0.45, -0.50, 0.45);
-		glVertex3f(-0.50, -0.45, 0.45);
-		glVertex3f(-0.50, -0.45, -0.45);
+		glVertex3f(-CUBEROUND, -CUBELEN, -CUBEROUND);
+		glVertex3f(-CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(-CUBELEN, -CUBEROUND, CUBEROUND);
+		glVertex3f(-CUBELEN, -CUBEROUND, -CUBEROUND);
 		glNormal3f(1.00, 1.00, 0.00);
-		glVertex3f(0.45, 0.50, -0.45);
-		glVertex3f(0.45, 0.50, 0.45);
-		glVertex3f(0.50, 0.45, 0.45);
-		glVertex3f(0.50, 0.45, -0.45);
+		glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
+		glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
+		glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
 		glNormal3f(-1.00, 1.00, 0.00);
-		glVertex3f(-0.50, 0.45, -0.45);
-		glVertex3f(-0.50, 0.45, 0.45);
-		glVertex3f(-0.45, 0.50, 0.45);
-		glVertex3f(-0.45, 0.50, -0.45);
+		glVertex3f(-CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(-CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBELEN, -CUBEROUND);
 		glNormal3f(1.00, -1.00, 0.00);
-		glVertex3f(0.50, -0.45, -0.45);
-		glVertex3f(0.50, -0.45, 0.45);
-		glVertex3f(0.45, -0.50, 0.45);
-		glVertex3f(0.45, -0.50, -0.45);
+		glVertex3f(CUBELEN, -CUBEROUND, -CUBEROUND);
+		glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBELEN, -CUBEROUND);
 		glNormal3f(0.00, -1.00, -1.00);
-		glVertex3f(-0.45, -0.45, -0.50);
-		glVertex3f(0.45, -0.45, -0.50);
-		glVertex3f(0.45, -0.50, -0.45);
-		glVertex3f(-0.45, -0.50, -0.45);
+		glVertex3f(-CUBEROUND, -CUBEROUND, -CUBELEN);
+		glVertex3f(CUBEROUND, -CUBEROUND, -CUBELEN);
+		glVertex3f(CUBEROUND, -CUBELEN, -CUBEROUND);
+		glVertex3f(-CUBEROUND, -CUBELEN, -CUBEROUND);
 		glNormal3f(0.00, 1.00, 1.00);
-		glVertex3f(-0.45, 0.45, 0.50);
-		glVertex3f(0.45, 0.45, 0.50);
-		glVertex3f(0.45, 0.50, 0.45);
-		glVertex3f(-0.45, 0.50, 0.45);
+		glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
 		glNormal3f(0.00, -1.00, 1.00);
-		glVertex3f(-0.45, -0.50, 0.45);
-		glVertex3f(0.45, -0.50, 0.45);
-		glVertex3f(0.45, -0.45, 0.50);
-		glVertex3f(-0.45, -0.45, 0.50);
+		glVertex3f(-CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
+		glVertex3f(-CUBEROUND, -CUBEROUND, CUBELEN);
 		glNormal3f(0.00, 1.00, -1.00);
-		glVertex3f(-0.45, 0.50, -0.45);
-		glVertex3f(0.45, 0.50, -0.45);
-		glVertex3f(0.45, 0.45, -0.50);
-		glVertex3f(-0.45, 0.45, -0.50);
+		glVertex3f(-CUBEROUND, CUBELEN, -CUBEROUND);
+		glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
+		glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
+		glVertex3f(-CUBEROUND, CUBEROUND, -CUBELEN);
 		glNormal3f(-1.00, 0.00, -1.00);
-		glVertex3f(-0.50, -0.45, -0.45);
-		glVertex3f(-0.50, 0.45, -0.45);
-		glVertex3f(-0.45, 0.45, -0.50);
-		glVertex3f(-0.45, -0.45, -0.50);
+		glVertex3f(-CUBELEN, -CUBEROUND, -CUBEROUND);
+		glVertex3f(-CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBEROUND, -CUBELEN);
+		glVertex3f(-CUBEROUND, -CUBEROUND, -CUBELEN);
 		glNormal3f(1.00, 0.00, 1.00);
-		glVertex3f(0.50, -0.45, 0.45);
-		glVertex3f(0.50, 0.45, 0.45);
-		glVertex3f(0.45, 0.45, 0.50);
-		glVertex3f(0.45, -0.45, 0.50);
+		glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
+		glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
 		glNormal3f(1.00, 0.00, -1.00);
-		glVertex3f(0.45, -0.45, -0.50);
-		glVertex3f(0.45, 0.45, -0.50);
-		glVertex3f(0.50, 0.45, -0.45);
-		glVertex3f(0.50, -0.45, -0.45);
+		glVertex3f(CUBEROUND, -CUBEROUND, -CUBELEN);
+		glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
+		glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(CUBELEN, -CUBEROUND, -CUBEROUND);
 		glNormal3f(-1.00, 0.00, 1.00);
-		glVertex3f(-0.45, -0.45, 0.50);
-		glVertex3f(-0.45, 0.45, 0.50);
-		glVertex3f(-0.50, 0.45, 0.45);
-		glVertex3f(-0.50, -0.45, 0.45);
+		glVertex3f(-CUBEROUND, -CUBEROUND, CUBELEN);
+		glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(-CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(-CUBELEN, -CUBEROUND, CUBEROUND);
 		glEnd();
 		glBegin(GL_TRIANGLES);
 		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
+		/* Corners of cubit */
 		glNormal3f(1.00, 1.00, 1.00);
-		glVertex3f(0.45, 0.45, 0.50);
-		glVertex3f(0.50, 0.45, 0.45);
-		glVertex3f(0.45, 0.50, 0.45);
+		glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
+		glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
 		glNormal3f(-1.00, -1.00, -1.00);
-		glVertex3f(-0.45, -0.50, -0.45);
-		glVertex3f(-0.50, -0.45, -0.45);
-		glVertex3f(-0.45, -0.45, -0.50);
+		glVertex3f(-CUBEROUND, -CUBELEN, -CUBEROUND);
+		glVertex3f(-CUBELEN, -CUBEROUND, -CUBEROUND);
+		glVertex3f(-CUBEROUND, -CUBEROUND, -CUBELEN);
 		glNormal3f(-1.00, 1.00, 1.00);
-		glVertex3f(-0.45, 0.45, 0.50);
-		glVertex3f(-0.45, 0.50, 0.45);
-		glVertex3f(-0.50, 0.45, 0.45);
+		glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
+		glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
+		glVertex3f(-CUBELEN, CUBEROUND, CUBEROUND);
 		glNormal3f(1.00, -1.00, -1.00);
-		glVertex3f(0.50, -0.45, -0.45);
-		glVertex3f(0.45, -0.50, -0.45);
-		glVertex3f(0.45, -0.45, -0.50);
+		glVertex3f(CUBELEN, -CUBEROUND, -CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBELEN, -CUBEROUND);
+		glVertex3f(CUBEROUND, -CUBEROUND, -CUBELEN);
 		glNormal3f(1.00, -1.00, 1.00);
-		glVertex3f(0.45, -0.45, 0.50);
-		glVertex3f(0.45, -0.50, 0.45);
-		glVertex3f(0.50, -0.45, 0.45);
+		glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
+		glVertex3f(CUBEROUND, -CUBELEN, CUBEROUND);
+		glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
 		glNormal3f(-1.00, 1.00, -1.00);
-		glVertex3f(-0.50, 0.45, -0.45);
-		glVertex3f(-0.45, 0.50, -0.45);
-		glVertex3f(-0.45, 0.45, -0.50);
+		glVertex3f(-CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBELEN, -CUBEROUND);
+		glVertex3f(-CUBEROUND, CUBEROUND, -CUBELEN);
 		glNormal3f(-1.00, -1.00, 1.00);
-		glVertex3f(-0.45, -0.45, 0.50);
-		glVertex3f(-0.50, -0.45, 0.45);
-		glVertex3f(-0.45, -0.50, 0.45);
+		glVertex3f(-CUBEROUND, -CUBEROUND, CUBELEN);
+		glVertex3f(-CUBELEN, -CUBEROUND, CUBEROUND);
+		glVertex3f(-CUBEROUND, -CUBELEN, CUBEROUND);
 		glNormal3f(1.00, 1.00, -1.00);
-		glVertex3f(0.50, 0.45, -0.45);
-		glVertex3f(0.45, 0.45, -0.50);
-		glVertex3f(0.45, 0.50, -0.45);
+		glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
+		glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
+		glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
 		glEnd();
 		glEndList();
 		rp->AreObjectsDefined[ObjCubit] = 1;
@@ -693,89 +692,98 @@ draw_cubit(ModeInfo * mi,
 		(void) printf("Cubit drawn quickly\n");
 #endif
 	}
+}
 
+static void
+draw_cubit(ModeInfo * mi,
+	   int back, int front, int left, int right, int bottom, int top)
+{
+	rubikstruct *rp = &rubik[MI_SCREEN(mi)];
+	int         mono = MI_IS_MONO(mi);
+
+	draw_stickerless_cubit(rp);
 	if (back != NO_FACE) {
 		glBegin(GL_POLYGON);
 		pickcolor(back, mono);
 		glNormal3f(0.00, 0.00, -1.00);
-		glVertex3f(-0.35, 0.40, -0.51);
-		glVertex3f(0.35, 0.40, -0.51);
-		glVertex3f(0.40, 0.35, -0.51);
-		glVertex3f(0.40, -0.35, -0.51);
-		glVertex3f(0.35, -0.40, -0.51);
-		glVertex3f(-0.35, -0.40, -0.51);
-		glVertex3f(-0.40, -0.35, -0.51);
-		glVertex3f(-0.40, 0.35, -0.51);
+		glVertex3f(-STICKERSHORT, STICKERLONG, -STICKERDEPTH);
+		glVertex3f(STICKERSHORT, STICKERLONG, -STICKERDEPTH);
+		glVertex3f(STICKERLONG, STICKERSHORT, -STICKERDEPTH);
+		glVertex3f(STICKERLONG, -STICKERSHORT, -STICKERDEPTH);
+		glVertex3f(STICKERSHORT, -STICKERLONG, -STICKERDEPTH);
+		glVertex3f(-STICKERSHORT, -STICKERLONG, -STICKERDEPTH);
+		glVertex3f(-STICKERLONG, -STICKERSHORT, -STICKERDEPTH);
+		glVertex3f(-STICKERLONG, STICKERSHORT, -STICKERDEPTH);
 		glEnd();
 	}
 	if (front != NO_FACE) {
 		glBegin(GL_POLYGON);
 		pickcolor(front, mono);
 		glNormal3f(0.00, 0.00, 1.00);
-		glVertex3f(-0.35, -0.40, 0.51);
-		glVertex3f(0.35, -0.40, 0.51);
-		glVertex3f(0.40, -0.35, 0.51);
-		glVertex3f(0.40, 0.35, 0.51);
-		glVertex3f(0.35, 0.40, 0.51);
-		glVertex3f(-0.35, 0.40, 0.51);
-		glVertex3f(-0.40, 0.35, 0.51);
-		glVertex3f(-0.40, -0.35, 0.51);
+		glVertex3f(-STICKERSHORT, -STICKERLONG, STICKERDEPTH);
+		glVertex3f(STICKERSHORT, -STICKERLONG, STICKERDEPTH);
+		glVertex3f(STICKERLONG, -STICKERSHORT, STICKERDEPTH);
+		glVertex3f(STICKERLONG, STICKERSHORT, STICKERDEPTH);
+		glVertex3f(STICKERSHORT, STICKERLONG, STICKERDEPTH);
+		glVertex3f(-STICKERSHORT, STICKERLONG, STICKERDEPTH);
+		glVertex3f(-STICKERLONG, STICKERSHORT, STICKERDEPTH);
+		glVertex3f(-STICKERLONG, -STICKERSHORT, STICKERDEPTH);
 		glEnd();
 	}
 	if (left != NO_FACE) {
 		glBegin(GL_POLYGON);
 		pickcolor(left, mono);
 		glNormal3f(-1.00, 0.00, 0.00);
-		glVertex3f(-0.51, -0.35, 0.40);
-		glVertex3f(-0.51, 0.35, 0.40);
-		glVertex3f(-0.51, 0.40, 0.35);
-		glVertex3f(-0.51, 0.40, -0.35);
-		glVertex3f(-0.51, 0.35, -0.40);
-		glVertex3f(-0.51, -0.35, -0.40);
-		glVertex3f(-0.51, -0.40, -0.35);
-		glVertex3f(-0.51, -0.40, 0.35);
+		glVertex3f(-STICKERDEPTH, -STICKERSHORT, STICKERLONG);
+		glVertex3f(-STICKERDEPTH, STICKERSHORT, STICKERLONG);
+		glVertex3f(-STICKERDEPTH, STICKERLONG, STICKERSHORT);
+		glVertex3f(-STICKERDEPTH, STICKERLONG, -STICKERSHORT);
+		glVertex3f(-STICKERDEPTH, STICKERSHORT, -STICKERLONG);
+		glVertex3f(-STICKERDEPTH, -STICKERSHORT, -STICKERLONG);
+		glVertex3f(-STICKERDEPTH, -STICKERLONG, -STICKERSHORT);
+		glVertex3f(-STICKERDEPTH, -STICKERLONG, STICKERSHORT);
 		glEnd();
 	}
 	if (right != NO_FACE) {
 		glBegin(GL_POLYGON);
 		pickcolor(right, mono);
 		glNormal3f(1.00, 0.00, 0.00);
-		glVertex3f(0.51, -0.35, -0.40);
-		glVertex3f(0.51, 0.35, -0.40);
-		glVertex3f(0.51, 0.40, -0.35);
-		glVertex3f(0.51, 0.40, 0.35);
-		glVertex3f(0.51, 0.35, 0.40);
-		glVertex3f(0.51, -0.35, 0.40);
-		glVertex3f(0.51, -0.40, 0.35);
-		glVertex3f(0.51, -0.40, -0.35);
+		glVertex3f(STICKERDEPTH, -STICKERSHORT, -STICKERLONG);
+		glVertex3f(STICKERDEPTH, STICKERSHORT, -STICKERLONG);
+		glVertex3f(STICKERDEPTH, STICKERLONG, -STICKERSHORT);
+		glVertex3f(STICKERDEPTH, STICKERLONG, STICKERSHORT);
+		glVertex3f(STICKERDEPTH, STICKERSHORT, STICKERLONG);
+		glVertex3f(STICKERDEPTH, -STICKERSHORT, STICKERLONG);
+		glVertex3f(STICKERDEPTH, -STICKERLONG, STICKERSHORT);
+		glVertex3f(STICKERDEPTH, -STICKERLONG, -STICKERSHORT);
 		glEnd();
 	}
 	if (bottom != NO_FACE) {
 		glBegin(GL_POLYGON);
 		pickcolor(bottom, mono);
 		glNormal3f(0.00, -1.00, 0.00);
-		glVertex3f(0.40, -0.51, -0.35);
-		glVertex3f(0.40, -0.51, 0.35);
-		glVertex3f(0.35, -0.51, 0.40);
-		glVertex3f(-0.35, -0.51, 0.40);
-		glVertex3f(-0.40, -0.51, 0.35);
-		glVertex3f(-0.40, -0.51, -0.35);
-		glVertex3f(-0.35, -0.51, -0.40);
-		glVertex3f(0.35, -0.51, -0.40);
+		glVertex3f(STICKERLONG, -STICKERDEPTH, -STICKERSHORT);
+		glVertex3f(STICKERLONG, -STICKERDEPTH, STICKERSHORT);
+		glVertex3f(STICKERSHORT, -STICKERDEPTH, STICKERLONG);
+		glVertex3f(-STICKERSHORT, -STICKERDEPTH, STICKERLONG);
+		glVertex3f(-STICKERLONG, -STICKERDEPTH, STICKERSHORT);
+		glVertex3f(-STICKERLONG, -STICKERDEPTH, -STICKERSHORT);
+		glVertex3f(-STICKERSHORT, -STICKERDEPTH, -STICKERLONG);
+		glVertex3f(STICKERSHORT, -STICKERDEPTH, -STICKERLONG);
 		glEnd();
 	}
 	if (top != NO_FACE) {
 		glBegin(GL_POLYGON);
 		pickcolor(top, mono);
 		glNormal3f(0.00, 1.00, 0.00);
-		glVertex3f(-0.40, 0.51, -0.35);
-		glVertex3f(-0.40, 0.51, 0.35);
-		glVertex3f(-0.35, 0.51, 0.40);
-		glVertex3f(0.35, 0.51, 0.40);
-		glVertex3f(0.40, 0.51, 0.35);
-		glVertex3f(0.40, 0.51, -0.35);
-		glVertex3f(0.35, 0.51, -0.40);
-		glVertex3f(-0.35, 0.51, -0.40);
+		glVertex3f(-STICKERLONG, STICKERDEPTH, -STICKERSHORT);
+		glVertex3f(-STICKERLONG, STICKERDEPTH, STICKERSHORT);
+		glVertex3f(-STICKERSHORT, STICKERDEPTH, STICKERLONG);
+		glVertex3f(STICKERSHORT, STICKERDEPTH, STICKERLONG);
+		glVertex3f(STICKERLONG, STICKERDEPTH, STICKERSHORT);
+		glVertex3f(STICKERLONG, STICKERDEPTH, -STICKERSHORT);
+		glVertex3f(STICKERSHORT, STICKERDEPTH, -STICKERLONG);
+		glVertex3f(-STICKERSHORT, STICKERDEPTH, -STICKERLONG);
 		glEnd();
 	}
 }
@@ -800,7 +808,7 @@ convertMove(rubikstruct * rp, RubikMove move, RubikSlice * slice)
 		else
 			(*slice).depth = move.position % sizeOfRow;
 	} else { /* (plane.face == 0 ||  *//* HORIZONTAL *//*
-	             (plane.face == 2 && (move.face == 0 || move.face == 4))) */
+		(plane.face == 2 && (move.face == 0 || move.face == 4))) */
 		if ((*slice).rotation == CW)
 			(*slice).depth = sizeOfColumn - 1 - move.position /
 				sizeOfRow;
@@ -812,7 +820,7 @@ convertMove(rubikstruct * rp, RubikMove move, RubikSlice * slice)
 		(*slice).rotation = ((*slice).rotation == CW) ? CCW : CW;
 }
 
-/* Assume for the moment that the size is at least 2 */
+/* Assume the size is at least 2, or its just not challenging... */
 static void
 draw_cube(ModeInfo * mi)
 {
@@ -892,7 +900,7 @@ draw_cube(ModeInfo * mi)
 					   NO_FACE, NO_FACE,
 					   rp->cubeLoc[BOTTOM_FACE][i + MAXSIZEX * FIRSTZ].face, NO_FACE);
 			}
-			glTranslatef(1, 0, -SZ);
+			glTranslatef(S1, 0, -SZ);
 			draw_cubit(mi,
 				   rp->cubeLoc[BACK_FACE][LASTX + MAXSIZEX * FIRSTY].face, NO_FACE,
 				   NO_FACE, rp->cubeLoc[RIGHT_FACE][LASTZ + MAXSIZEZ * LASTY].face,
@@ -1750,26 +1758,26 @@ shuffle(ModeInfo * mi)
 	}
 
 	for (i = 0; i < rp->storedmoves; i++) {
-		int         condition;
+		Bool condition;
 
 		do {
-			move.face = NRAND(6);
-			move.direction = NRAND(4);	/* Exclude CW and CCW, its ok */
+			move.face = NRAND(MAXFACES);
+			move.direction = NRAND(MAXORIENT);	/* Exclude CW and CCW, its ok */
 			move.position = NRAND(sizeFace(rp, move.face));
- 		    rp->degreeTurn = (checkFaceSquare(rp,
+			rp->degreeTurn = (checkFaceSquare(rp,
 				rowToRotate[move.face][move.direction])) ? 90 : 180;
-			condition = 1;
+			condition = True;
 			if (i > 0) {	/* avoid immediate undoing moves */
 				if (compare_moves(rp, move, rp->moves[i - 1], True))
-					condition = 0;
+					condition = False;
 				if (rp->degreeTurn == 180 &&
 				    compare_moves(rp, move, rp->moves[i - 1], False))
-					condition = 0;
+					condition = False;
 			}
 			if (i > 1)	/* avoid 3 consecutive identical moves */
 				if (compare_moves(rp, move, rp->moves[i - 1], False) &&
 				    compare_moves(rp, move, rp->moves[i - 2], False))
-					condition = 0;
+					condition = False;
 			/*
 			 * Still some silly moves being made....
 			 */
@@ -1853,9 +1861,9 @@ init_rubik(ModeInfo * mi)
 	if ((rp->glx_context = init_GL(mi)) != NULL) {
 
 		reshape(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
-        glDrawBuffer(GL_BACK);
-        if (!glIsList(objects))
-		  objects = glGenLists(1);
+		glDrawBuffer(GL_BACK);
+		if (!glIsList(objects))
+			objects = glGenLists(MaxObj);
 		pinit(mi);
 	} else {
 		MI_CLEARWINDOW(mi);
@@ -1865,7 +1873,7 @@ init_rubik(ModeInfo * mi)
 void
 draw_rubik(ModeInfo * mi)
 {
-	int         bounced = 0;
+	Bool bounced = False;
 
 	rubikstruct *rp = &rubik[MI_SCREEN(mi)];
 	Display    *display = MI_DISPLAY(mi);
@@ -1890,22 +1898,22 @@ draw_rubik(ModeInfo * mi)
 	if (rp->PY < -1) {
 		rp->PY += (-1) - (rp->PY);
 		rp->VY = -rp->VY;
-		bounced = 1;
+		bounced = True;
 	}
 	if (rp->PY > 1) {
 		rp->PY -= (rp->PY) - 1;
 		rp->VY = -rp->VY;
-		bounced = 1;
+		bounced = True;
 	}
 	if (rp->PX < -1) {
 		rp->PX += (-1) - (rp->PX);
 		rp->VX = -rp->VX;
-		bounced = 1;
+		bounced = True;
 	}
 	if (rp->PX > 1) {
 		rp->PX -= (rp->PX) - 1;
 		rp->VX = -rp->VX;
-		bounced = 1;
+		bounced = True;
 	}
 	if (bounced) {
 		rp->VX += ((float) LRAND() / (float) MAXRAND) * 0.02 - 0.01;
@@ -2036,6 +2044,9 @@ release_rubik(ModeInfo * mi)
 		(void) free((void *) rubik);
 		rubik = NULL;
 	}
+	if (glIsList(objects)) {
+		glDeleteLists(objects, 1);
+	}
 	FreeAllGL(mi);
 }
 
