@@ -98,13 +98,16 @@ ModStruct   stairs_description =
 #define Pi                         M_PI
 #endif
 
+#define ObjSphere    0
+#define MaxObj       1
+
 /*************************************************************************/
 
 typedef struct {
 	GLint       WindH, WindW;
 	GLfloat     step;
 	Bool        direction;
-	int         AreObjectsDefined[1];
+	int         AreObjectsDefined[MaxObj];
 	int         sphere_position;
 	GLXContext *glx_context;
 } stairsstruct;
@@ -196,8 +199,6 @@ static float positions[] =
 static stairsstruct *stairs = NULL;
 static GLuint objects;
 
-#define ObjSphere    0
-
 #define PlankWidth      3.0
 #define PlankHeight     0.35
 #define PlankThickness  0.15
@@ -407,7 +408,7 @@ init_stairs(ModeInfo * mi)
 		reshape(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 		glDrawBuffer(GL_BACK);
 		if (!glIsList(objects))
-			objects = glGenLists(1);
+			objects = glGenLists(MaxObj);
 		pinit();
 	} else {
 		MI_CLEARWINDOW(mi);
