@@ -108,15 +108,15 @@ static float spinspeed;
 
 static XrmOptionDescRec opts[] =
 {
-  {"-spinspeed", ".superquadrics.spinspeed", XrmoptionSepArg, (caddr_t) NULL}
+  {(char *) "-spinspeed", (char *) ".superquadrics.spinspeed", XrmoptionSepArg, (caddr_t) NULL}
 };
 static argtype vars[] =
 {
-  {(caddr_t *) & spinspeed, "spinspeed", "Spinspeed", DEF_SPINSPEED, t_Float}
+  {(caddr_t *) & spinspeed, (char *) "spinspeed", (char *) "Spinspeed", (char *) DEF_SPINSPEED, t_Float}
 };
 static OptionStruct desc[] =
 {
-	{"-spinspeed num", "speed of rotation, in degrees per frame"}
+	{(char *) "-spinspeed num", (char *) "speed of rotation, in degrees per frame"}
 };
 
 ModeSpecOpt superquadrics_opts =
