@@ -35,7 +35,7 @@ static const char sccsid[] = "@(#)goop.c  4.10 98/03/24 xlockmore";
  * the above copyright notice appear in all copies and that both that
  * copyright notice and this permission notice appear in supporting
  * documentation.  No representations are made about the suitability of this
- * software for any purpose.  It is provided "as is" without express or 
+ * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  */
 
@@ -103,8 +103,8 @@ ModeSpecOpt goop_opts =
 #ifdef USE_MODULES
 ModStruct   goop_description =
 {"goop", "init_goop", "draw_goop", "release_goop",
- "refresh_goop", "init_goop", NULL, &goop_opts,
- 10000, -5, 1, 1, 64, 1.0, "",
+ "init_goop", "init_goop", NULL, &goop_opts,
+ 10000, -12, 1, 1, 64, 1.0, "",
  "Shows goop from a lava lamp", 0, NULL};
 
 #endif
@@ -140,7 +140,7 @@ typedef struct {
 enum goop_mode {
 	transparent,
 	opaque,
-	xor,
+	xored,
 	outline
 };
 
@@ -411,7 +411,7 @@ init_goop(ModeInfo * mi)
 	gp = &goops[MI_SCREEN(mi)];
 
 
-	gp->mode = (False /* xor init */ ? xor
+	gp->mode = (False /* xor init */ ? xored
 		    : (True /* transparent init */ ? transparent : opaque));
 
 	gp->width = MI_WIDTH(mi);
@@ -486,7 +486,7 @@ init_goop(ModeInfo * mi)
 		}
 	}
 	gp->pixmap = XCreatePixmap(display, window, MI_WIDTH(mi), MI_HEIGHT(mi),
-				   (gp->mode == xor ? 1 : MI_DEPTH(mi)));
+				   (gp->mode == xored ? 1 : MI_DEPTH(mi)));
 
 	gcv.background = gp->background;
 	gcv.foreground = 255;	/* init */
@@ -532,7 +532,7 @@ draw_goop(ModeInfo * mi)
 				  gp->width, gp->height, 0, 0);
 			break;
 
-		case xor:
+		case xored:
 			XSetFunction(display, gp->pixmap_gc, GXcopy);
 			XSetForeground(display, gp->pixmap_gc, 0);
 			XFillRectangle(display, gp->pixmap, gp->pixmap_gc, 0, 0,
