@@ -22,16 +22,22 @@ static const char sccsid[] = "@(#)loop.c	4.13 98/10/18 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 18-Oct-98: Started creating a hexagon version, probably will not work
- *            for a while since some work has to go into getting not
- *            only the program to handle the hexagonal data but the loop
- *            has to be "programmed" as well.  I suspect it should be easier
- *            than the original since the loop will have six sides to
- *            store its genes (data).
- * 10-May-97: Compatible with xscreensaver
- * 15-Nov-95: Coded from Chris Langton's Self-Reproduction in Cellular
- *            Automata Physica 10D 135-144 1984
- *            also used wire.c as a guide.
+ * 16-Jun-2000: Fully coded the hexagonal rules.  (Rules that end up in
+ *   state zero were not bothered with since a calloc was used to set
+ *   non-explicit rules to zero.  This allows the compile-time option
+ *   RAND_RULES to work here (at least to generation 540).)
+ *   Also added compile-time option DELAYDEBUGLOOP for debugging life form.
+ *   This also turns off the random initial direction of the loop.
+ *   Set DELAYDEBUGLOOP to be 10 and use with something like this:
+ *   xlock -mode loop -neighbors 6 -size 5 -delay 1 -count 540 -nolock
+ * 18-Oct-1998: Started creating a hexagon version.
+ *   It proved not that difficult because I used Langton's Loop
+ *   as a guide, hexagon have more neighbors so there is more
+ *   freedom to program, and the loop will has six sides to
+ *   store its genes (data).
+ * 10-May-1997: Compatible with xscreensaver
+ * 15-Nov-1995: Coded from Chris Langton's Self-Reproduction in Cellular
+ *   Automata Physica 10D 135-144 1984, also used wire.c as a guide.
  */
 
 /*-
@@ -59,7 +65,10 @@ static const char sccsid[] = "@(#)loop.c	4.13 98/10/18 xlockmore";
    machine is not contained in the loop.  This is a simplification of
    von Neumann and Codd's self-producing Turing machine.
    The data spinning around could be viewed as both its DNA and its internal
-   clock.
+   clock.  The program can be initalized to have the loop spin both ways...
+   but only one way around will work for a given rule.  An open question (at
+   least to me): Is handedness a requirement for life?  Here there is
+   handedness at both the initial condition and the transition rule.
  */
 
 #ifdef STANDALONE
@@ -90,17 +99,17 @@ static int  neighbors;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-neighbors", ".loop.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-neighbors", (char *) ".loop.neighbors", XrmoptionSepArg, (caddr_t) NULL}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int}
+	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int}
 };
 
 static OptionStruct desc[] =
 {
-	{"-neighbors num", "squares 4 or hexagons 6"}
+	{(char *) "-neighbors num", (char *) "squares 4 or hexagons 6"}
 };
 
 ModeSpecOpt loop_opts =
@@ -122,6 +131,16 @@ ModStruct   loop_description =
 
 static int  local_neighbors = 0;
 
+#if 0
+/* Used to fast forward to troubled generations, mainly used for debugging.
+   -delay 1 -count 170 -neighbors 6  # divisions starts
+   540 first cell collision
+   1111 mutant being born from 2 parents
+   1156 mutant born 
+ */
+#define DELAYDEBUGLOOP 10
+#endif
+
 #define COLORS 8
 #define REALCOLORS (COLORS-2)
 #define MINLOOPS 1
@@ -135,12 +154,14 @@ static int  local_neighbors = 0;
 #define ADAM_LOOPY 10
 #endif
 #define MINGRIDSIZE (3*ADAM_LOOPX)
+#if 0
 /* TRIA stuff was an attempt to make a triangular lifeform on a
-   hex grid but I got bored.  You probably need an additional 7th
-   state for a coherent step by step process of separation and
+   hexagonal grid but I got bored.  You may need an additional 7th
+   state for a coherent step by step process of cell separation and
    initial stem development.
  */
-/* #define TRIA 1 */
+#define TRIA 1
+#endif
 #ifdef TRIA
 #define HEX_ADAM_SIZE 3 /* MIN 3 */
 #else
@@ -175,7 +196,7 @@ typedef struct {
 	int         mincol, minrow, maxcol, maxrow;
 	int         width, height;
 	int         redrawing, redrawpos;
-	Bool        dead;
+	Bool        dead, clockwise;
 	unsigned char *newcells, *oldcells;
 	int         ncells[COLORS];
 	CellList   *cellList[COLORS];
@@ -192,7 +213,16 @@ static loopstruct *loops = NULL;
 #define TRANSITION(TT,V) V=TT&7;TT>>=3
 #define TABLE(R,T,L,B) (table[((B)<<9)|((L)<<6)|((T)<<3)|(R)])
 #define HEX_TABLE(R,T,t,l,b,B) (table[((B)<<15)|((b)<<12)|((l)<<9)|((t)<<6)|((T)<<3)|(R)])
-#ifdef RAND_RULES		/* Hack, see below */
+
+#if 0
+/* Instead of setting "unused" state rules to zero it randomizes them.
+   These rules take over when something unexpected happens... like when a
+   cell hits a wall (the end of the screen).
+ */
+#define RAND_RULES
+#endif
+
+#ifdef RAND_RULES
 #define TABLE_IN(C,R,T,L,B,I) (TABLE(R,T,L,B)&=~(7<<((C)*3)));\
 (TABLE(R,T,L,B)|=((I)<<((C)*3)))
 #define HEX_TABLE_IN(C,R,T,t,l,b,B,I) (HEX_TABLE(R,T,t,l,b,B)&=~(7<<((C)*3)));\
@@ -204,8 +234,8 @@ static loopstruct *loops = NULL;
 #define TABLE_OUT(C,R,T,L,B) ((TABLE(R,T,L,B)>>((C)*3))&7)
 #define HEX_TABLE_OUT(C,R,T,t,l,b,B) ((HEX_TABLE(R,T,t,l,b,B)>>((C)*3))&7)
 
-static unsigned int *table = NULL;	/* 8*8*8*8 = 2^12 = 2^3^4 = 4K */
-  /* 8*8*8*8*8*8 = too big? */
+static unsigned int *table = NULL;	/* 8*8*8*8 = 2^12 = 2^3^4 = 4096 */
+  /* 8*8*8*8*8*8 = 2^18 = 2^3^6 = 262144 = too big? */
 
 static char plots[NEIGHBORKINDS] =
 {
@@ -480,7 +510,7 @@ static unsigned int hex_transition_table[] =
     001224251,
     010022152, 010251221, 010522121, 011212151, 011221251,
     011215221,
-    020000220, 020002152, 020020220, 020021020, 020022152,
+    020000220, 020002152, 020020220, 020022152,
     020021422, 020022152, 020022522, 020025425, 020050422,
     020051022, 020051122, 020211122, 020211222, 020215222,
     020245122,
@@ -572,7 +602,6 @@ static unsigned int hex_transition_table[] =
     020212122,
     020027222,
     020024222,
-    020020222,
     020212722,
     020212422,
     020202122,
@@ -584,6 +613,33 @@ static unsigned int hex_transition_table[] =
     020212052,
 
     020205052,
+    070221250,
+
+    000000050, 000005220, 000002270, 070252220,
+    000000450, 000007220,
+    000220220, 000202220, 000022020, 000020220,
+
+    000222040,
+    000220440,
+    000022040,
+    000040220,
+
+    000252220,
+    050221120, 010221520,
+    002222220,
+
+    000070220, 000220720,
+    000020520, 000070250, 000222070, 000027020,
+    000022070, 000202270, 000024020, 000220420,
+    000220270, 000220240, 000072020, 000042020,
+    000002020, 000002070, 000020270, 000020250,
+    000270270, 000007020, 000040270,
+
+    /* Collision starts (gen 540), not sure to have rules to save it
+       or depend on calloc to intialize remaining rules to 0 so that
+       the mutant will be born
+     */
+    000050220,
 #endif
 };
 
@@ -917,7 +973,7 @@ draw_state(ModeInfo * mi, int state)
 }
 
 static int
-init_table(void)
+init_table()
 {
 	if (table == NULL) {
 		int mult = 1;
@@ -935,13 +991,18 @@ init_table(void)
 			return 1;
 		}
 
+
 #ifdef RAND_RULES
 		/* Here I was interested to see what happens when it hits a wall....
 		   Rules not normally used take over... takes too much time though */
-		{
+		/* Each state = 3 bits */
+		if (MAXRAND < 16777216.0) {
 			for (j = 0; j < mult; j++) {
-				for (k = 0; k < 8; k++)
-					table[j] |= (unsigned int) ((unsigned int) (NRAND(8)) << (k * 3));
+				table[j] = (unsigned int) ((NRAND(4096) << 12) & NRAND(4096));
+			}
+		} else {
+			for  (j = 0; j < mult; j++) {
+				table[j] = (unsigned int) (NRAND(16777216));
 			}
 		}
 #endif
@@ -983,13 +1044,22 @@ init_adam(ModeInfo * mi)
 {
 	loopstruct *lp = &loops[MI_SCREEN(mi)];
 	XPoint      start, dirx, diry;
-	int         i, j;
+	int         i, j, dir;
 
-  if (local_neighbors == 6) {
+#ifdef DELAYDEBUGLOOP
+	lp->clockwise = 0;
+	if (!MI_COUNT(mi)) /* Probably doing testing so do not confuse */
+#endif
+	lp->clockwise = (Bool) (LRAND() & 1);
+#ifdef DELAYDEBUGLOOP
+	dir = 0;
+	if (!MI_COUNT(mi)) /* Probably doing testing so do not confuse */
+#endif
+	dir = NRAND(local_neighbors);
+	if (local_neighbors == 6) {
 		int k;
 
-		/* switch (0) */
-		switch (NRAND(6)) {
+		switch (dir) {
 			case 0:
 				start.x = (lp->bncols - HEX_ADAM_LOOPX / 2) / 2;
 				start.y = (lp->bnrows - HEX_ADAM_LOOPY) / 2;
@@ -1001,7 +1071,9 @@ init_adam(ModeInfo * mi)
 					for (i = 0; i < HEX_ADAM_LOOPX; i++) {
 						k = (((lp->bnrows / 2 + HEX_ADAM_LOOPY / 2) % 2) ? -j / 2 : -(j + 1) / 2);
 						lp->newcells[(start.y + j) * lp->bncols + start.x + i + k] =
-							hex_self_reproducing_loop[j][i];
+		 					(lp->clockwise) ?
+					hex_self_reproducing_loop[i][j] :
+					hex_self_reproducing_loop[j][i];
 					}
 				}
 				break;
@@ -1017,7 +1089,9 @@ init_adam(ModeInfo * mi)
 						k = (((lp->bnrows / 2 + (HEX_ADAM_LOOPX + HEX_ADAM_LOOPY) / 2) % 2)
               ? -(i + j + 1) / 2 : -(i + j) / 2);
 						lp->newcells[(start.y + j - i) * lp->bncols + start.x + i + j + k] =
-							hex_self_reproducing_loop[j][i];
+		 					(lp->clockwise) ?
+		 					hex_self_reproducing_loop[i][j] :
+		 					hex_self_reproducing_loop[j][i];
 					}
 				}
 				break;
@@ -1032,7 +1106,9 @@ init_adam(ModeInfo * mi)
 					for (i = 0; i < HEX_ADAM_LOOPY; i++) {
 						k = (((lp->bnrows / 2 + HEX_ADAM_LOOPX / 2) % 2) ? -(HEX_ADAM_LOOPX - j - 1) / 2 : -(HEX_ADAM_LOOPX - j) / 2);
 						lp->newcells[(start.y + j) * lp->bncols + start.x + i + k] =
-							hex_self_reproducing_loop[i][HEX_ADAM_LOOPX - j - 1];
+		 					(lp->clockwise) ?
+		 					hex_self_reproducing_loop[j][HEX_ADAM_LOOPX - i - 1] :
+		 					hex_self_reproducing_loop[i][HEX_ADAM_LOOPY - j - 1];
 					}
 				}
 				break;
@@ -1047,7 +1123,9 @@ init_adam(ModeInfo * mi)
 					for (i = 0; i < HEX_ADAM_LOOPX; i++) {
 						k = (((lp->bnrows / 2 + HEX_ADAM_LOOPY / 2) % 2) ? -j / 2 : -(j + 1) / 2);
 						lp->newcells[(start.y + j) * lp->bncols + start.x + i + k] =
-							hex_self_reproducing_loop[HEX_ADAM_LOOPY - j - 1][HEX_ADAM_LOOPX - i - 1];
+		 					(lp->clockwise) ?
+		 					hex_self_reproducing_loop[HEX_ADAM_LOOPX - i - 1][HEX_ADAM_LOOPY - j - 1] :
+		 					hex_self_reproducing_loop[HEX_ADAM_LOOPY - j - 1][HEX_ADAM_LOOPX - i - 1];
 					}
 				}
 				break;
@@ -1063,7 +1141,9 @@ init_adam(ModeInfo * mi)
 						k = (((lp->bnrows / 2 + (HEX_ADAM_LOOPX + HEX_ADAM_LOOPY) / 2) % 2)
               ? -(i + j + 1) / 2 : -(i + j) / 2);
 						lp->newcells[(start.y + j - i) * lp->bncols + start.x + i + j + k] =
-							hex_self_reproducing_loop[HEX_ADAM_LOOPY - j - 1][HEX_ADAM_LOOPX - i - 1];
+		 					(lp->clockwise) ?
+		 					hex_self_reproducing_loop[HEX_ADAM_LOOPX - i - 1][HEX_ADAM_LOOPY - j - 1] :
+		 					hex_self_reproducing_loop[HEX_ADAM_LOOPY - j - 1][HEX_ADAM_LOOPX - i - 1];
 					}
 				}
 				break;
@@ -1078,7 +1158,9 @@ init_adam(ModeInfo * mi)
 					for (i = 0; i < HEX_ADAM_LOOPY; i++) {
 						k = (((lp->bnrows / 2 + HEX_ADAM_LOOPX / 2) % 2) ? -(HEX_ADAM_LOOPX - j - 1) / 2 : -(HEX_ADAM_LOOPX - j) / 2);
 						lp->newcells[(start.y + j) * lp->bncols + start.x + i + k] =
-							hex_self_reproducing_loop[HEX_ADAM_LOOPX - i - 1][j];
+		 					(lp->clockwise) ?
+		 					hex_self_reproducing_loop[HEX_ADAM_LOOPY - j - 1][i] :
+		 					hex_self_reproducing_loop[HEX_ADAM_LOOPX - i - 1][j];
 					}
 				}
 				break;
@@ -1100,7 +1182,7 @@ init_adam(ModeInfo * mi)
 			 (void) printf ("\n");
 #endif
   } else {
-		switch (NRAND(4)) {
+		switch (dir) {
 			case 0:
 				start.x = (lp->bncols - ADAM_LOOPX) / 2;
 				start.y = (lp->bnrows - ADAM_LOOPY) / 2;
@@ -1138,12 +1220,14 @@ init_adam(ModeInfo * mi)
 			for (i = 0; i < ADAM_LOOPX; i++)
 				lp->newcells[(start.y + dirx.y * i + diry.y * j) * lp->bncols +
 					     start.x + dirx.x * i + diry.x * j] =
+					(lp->clockwise) ?
+					self_reproducing_loop[j][ADAM_LOOPX - i - 1] :
 					self_reproducing_loop[j][i];
 #if DEBUG
 		/* Draw right away */
 		drawcell(mi, start.x + dirx.x * i + diry.x * j - lp->bx,
 		 start.y + dirx.y * i + diry.y * j - lp->by,
-		 self_reproducing_loop[j][i]);
+		 (lp->clockwise) ? self_reproducing_loop[j][ADAM_LOOPX - i - i] : self_reproducing_loop[j][i]);
 #endif
 	}
 }
@@ -1173,9 +1257,13 @@ do_gen(loopstruct * lp)
 				}
 			}
 			if (local_neighbors == 6) {
-				*z = HEX_TABLE_OUT(c, n[0], n[1], n[2], n[3], n[4], n[5]);
+				*z = (lp->clockwise) ?
+					HEX_TABLE_OUT(c, n[5], n[4], n[3], n[2], n[1], n[0]) :
+					HEX_TABLE_OUT(c, n[0], n[1], n[2], n[3], n[4], n[5]);
 			} else {
-				*z = TABLE_OUT(c, n[0], n[1], n[2], n[3]);
+				*z = (lp->clockwise) ?
+					TABLE_OUT(c, n[3], n[2], n[1], n[0]) :
+					TABLE_OUT(c, n[0], n[1], n[2], n[3]);
 			}
 		}
 	}
@@ -1365,7 +1453,7 @@ init_loop(ModeInfo * mi)
 		release_loop(mi);
 		return;
 	}
-  if (init_table()) {
+	if (init_table()) {
 		release_loop(mi);
 		return;
 	}
@@ -1385,6 +1473,11 @@ draw_loop(ModeInfo * mi)
 	}
 	MI_IS_DRAWN(mi) = True;
 	lp->dead = True;
+#ifdef DELAYDEBUGLOOP
+	if (MI_COUNT(mi) && lp->generation > MI_COUNT(mi)) {
+		(void) sleep(DELAYDEBUGLOOP);
+	}
+#endif
 
 	for (j = lp->minrow; j <= lp->maxrow; j++) {
 		for (i = lp->mincol; i <= lp->maxcol; i++) {
