@@ -216,7 +216,7 @@ public:
 	int whichRank();
 	Colors whichColor();
 };
-inline Card::Card(Suits suit, int rank) { this->suit = suit; this->rank = rank;}
+inline Card::Card(Suits a_suit, int a_rank) { this->suit = a_suit; this->rank = a_rank;}
 inline Suits Card::whichSuit() { return this->suit;}
 inline int Card::whichRank() { return this->rank;}
 inline Colors Card::whichColor() { return ((whichSuit() % MAXCOLORS) ? red : black);}
@@ -254,17 +254,17 @@ inline int CardView::y() { return locationY; }
 inline void CardView::moveTo(int lx, int ly) { locationX = lx; locationY = ly; }
 
 //cardview.cc
-CardView::CardView(ModeInfo * mi, Card * card)
+CardView::CardView(ModeInfo * a_mi, Card * a_card)
 {
-	this->mi = mi;
-	this->card = card;
+	this->mi = a_mi;
+	this->card = a_card;
 	faceUp = False;
 	locationX = locationY = 0;
 }
 
-CardView::CardView(ModeInfo * mi, Suits suit, int rank)
+CardView::CardView(ModeInfo * a_mi, Suits suit, int rank)
 {
-	this->mi = mi;
+	this->mi = a_mi;
 	this->card = new Card(suit, rank);
 	faceUp = False;
 	locationX = locationY = 0;
@@ -286,7 +286,7 @@ void CardView::draw()
 		} else {
 			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		}
-		if (width() > 16 && height() > 18) {
+		if (width() > 16 && height() > 34) {
 #ifdef CENTERLABEL
 			XDrawString(display, window, gc,
 				x() + width() / 2 - strlen(RankNames[card->whichRank()]) * 8,
@@ -309,9 +309,15 @@ void CardView::draw()
 			x() + round(width() * 0.35), y() + round(height() * 0.55),
 			round(0.3 * width()), round(0.3 * height()));
 #else
-		drawSuit(mi, card->whichSuit(),
-			x() + 5, y() + 25,
-			round(0.3 * width()), round(0.3 * height()));
+		if (width() > 16 && height() > 34) {
+			drawSuit(mi, card->whichSuit(),
+				x() + 5, y() + 25,
+				round(0.3 * width()), round(0.3 * height()));
+		} else {
+			drawSuit(mi, card->whichSuit(),
+				x() + 2, y() + 2,
+				round(0.3 * width()), round(0.3 * height()));
+		}
 #endif
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		XDrawLine(display, window, gc,
@@ -386,10 +392,10 @@ private:
 	CardLink * link;
 };
 
-inline CardLink::CardLink(ModeInfo *mi, Suits suit, int rank) : CardView(mi, suit, rank) { ; }
-inline CardLink::CardLink(ModeInfo *mi, Card * card) : CardView(mi, card) { ; }
+inline CardLink::CardLink(ModeInfo *a_mi, Suits suit, int rank) : CardView(a_mi, suit, rank) { ; }
+inline CardLink::CardLink(ModeInfo *a_mi, Card * a_card) : CardView(a_mi, a_card) { ; }
 inline CardLink * CardLink::nextCard() { return link; }
-inline void CardLink::setLink(CardLink * card) { link = card; }
+inline void CardLink::setLink(CardLink * a_card) { link = a_card; }
 
 class CardPile
 {
@@ -415,7 +421,7 @@ protected:
 
 #define nilLink (CardLink *) 0
 
-inline CardPile::CardPile(ModeInfo * mi) { this->mi = mi; top = nilLink; }
+inline CardPile::CardPile(ModeInfo * a_mi) { this->mi = a_mi; top = nilLink; }
 
 class DealPile : public CardPile
 {
@@ -424,12 +430,12 @@ public:
 	virtual void cleanup();
 	void shuffle(CardPile *);
 };
-inline DealPile::DealPile(ModeInfo * mi) : CardPile(mi) { ; }
+inline DealPile::DealPile(ModeInfo * a_mi) : CardPile(a_mi) { ; }
 
 class SuitPile : public CardPile
 {
 public:
-	SuitPile(ModeInfo * mi, int s) : CardPile(mi) { suit = s; }
+	SuitPile(ModeInfo * a_mi, int s) : CardPile(a_mi) { suit = s; }
 	virtual void updateLocation(ModeInfo *);
 	virtual Bool canTake(Card *);
 private:
@@ -439,7 +445,7 @@ private:
 class AlternatePile : public CardPile
 {
 public:
-	AlternatePile(ModeInfo * mi, int p) : CardPile(mi) { pile = p; }
+	AlternatePile(ModeInfo * a_mi, int p) : CardPile(a_mi) { pile = p; }
 	virtual void updateLocation(ModeInfo *);
 	virtual void addCard(CardLink *);
 	virtual Bool canTake(Card *);
@@ -455,7 +461,7 @@ private:
 class DeckPile : public CardPile
 {
 public:
-	DeckPile(ModeInfo * mi) : CardPile(mi) { ; }
+	DeckPile(ModeInfo * a_mi) : CardPile(a_mi) { ; }
 	virtual void updateLocation(ModeInfo *);
 	virtual void addCard(CardLink *);
 	virtual void initialize();
@@ -466,7 +472,7 @@ public:
 class DiscardPile : public CardPile
 {
 public:
-	DiscardPile(ModeInfo * mi) : CardPile(mi) { ; }
+	DiscardPile(ModeInfo * a_mi) : CardPile(a_mi) { ; }
 	virtual void updateLocation(ModeInfo *);
 	virtual void addCard(CardLink *);
 	virtual Bool select(int, int);
@@ -536,7 +542,7 @@ void CardPile::addCard(CardLink * card)
 	}
 }
 
-void CardPile::updateLocation(ModeInfo * mi)
+void CardPile::updateLocation(ModeInfo * a_mi)
 {
 	;
 }
@@ -597,9 +603,9 @@ CardLink * CardPile::removeCard()
 	return p;
 }
 
-Bool CardPile::select(int x, int y)
+Bool CardPile::select(int a_x, int a_y)
 {
-	// from virtual, x & y unused
+	// from virtual, a_x & a_y unused
 	return select(True);
 }
 
@@ -634,7 +640,7 @@ void DealPile::shuffle(CardPile * pile)
 	}
 	// then pull them out, randomly, one at a time
 	for (; max > 0; max--) {
-		limit = ((LRAND() >> 3) % max) + 1;
+		limit = (int) ((LRAND() >> 3) % max) + 1;
 		for ( i= 1, p = top; i <= limit; ) {
 			while (p->isFaceUp())
 				p = p->nextCard();
@@ -648,9 +654,9 @@ void DealPile::shuffle(CardPile * pile)
 	}
 }
 
-void DeckPile::updateLocation(ModeInfo * mi)
+void DeckPile::updateLocation(ModeInfo * a_mi)
 {
-	solitarestruct *bp = &solitare[MI_SCREEN(mi)];
+	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 
 	//set pile
 	x = round(((bp->cardwidth + 2.0 * MAXSUITS * bp->cardwidth *
@@ -679,9 +685,9 @@ void DeckPile::addCard(CardLink *c)
 	CardPile::addCard(c);
 }
 
-Bool DeckPile::select(int x, int y)
+Bool DeckPile::select(int a_x, int a_y)
 {
-	// from virtual, x & y unused
+	// from virtual, a_x & a_y unused
 	return select(True);
 }
 
@@ -704,9 +710,9 @@ Bool DeckPile::select(Bool first)
 	return didSomething;
 }
 
-void DiscardPile::updateLocation(ModeInfo * mi)
+void DiscardPile::updateLocation(ModeInfo * a_mi)
 {
-	solitarestruct *bp = &solitare[MI_SCREEN(mi)];
+	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 
 	//set pile
 	x = round(((bp->cardwidth + 2.0 * MAXSUITS * bp->cardwidth *
@@ -728,9 +734,9 @@ void DiscardPile::addCard(CardLink *c)
 }
 
 // play the current face card
-Bool DiscardPile::select(int x, int y)
+Bool DiscardPile::select(int a_x, int a_y)
 {
-	// from virtual, x & y unused
+	// from virtual, a_x & a_y unused
 	return select(True);
 }
 
@@ -761,9 +767,9 @@ Bool DiscardPile::select(Bool first)
 	return False;
 }
 
-void SuitPile::updateLocation(ModeInfo * mi)
+void SuitPile::updateLocation(ModeInfo * a_mi)
 {
-	solitarestruct *bp = &solitare[MI_SCREEN(mi)];
+	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 
 	//set pile
 	x = round(((bp->cardwidth + 2.0 * suit * bp->cardwidth *
@@ -791,9 +797,9 @@ Bool SuitPile::canTake(Card * card)
 	return False;
 }
 
-void AlternatePile::updateLocation(ModeInfo * mi)
+void AlternatePile::updateLocation(ModeInfo * a_mi)
 {
-	solitarestruct *bp = &solitare[MI_SCREEN(mi)];
+	solitarestruct *bp = &solitare[MI_SCREEN(a_mi)];
 	int ty;
 
 	//set pile
@@ -827,11 +833,11 @@ void AlternatePile::updateLocation(ModeInfo * mi)
 void AlternatePile::initialize()
 {
 	solitarestruct *bp = &solitare[MI_SCREEN(mi)];
-	int pile;
+	int a_pile;
 
 	//put the right number of cards on the alternate
 	CardPile::initialize();
-	for (pile = 0; pile <= this->pile; pile++)
+	for (a_pile = 0; a_pile <= this->pile; a_pile++)
 		addCard((bp->game->deckPile)->removeCard());
 	// flip the last one
 	if (top != nilLink) {
@@ -880,7 +886,7 @@ Bool AlternatePile::canTake(Card *card)
 	return False;
 }
 
-void AlternatePile::copyBuild(CardLink *card, CardPile * pile)
+void AlternatePile::copyBuild(CardLink *card, CardPile * a_pile)
 {
 	CardLink *tempCard;
 
@@ -888,9 +894,9 @@ void AlternatePile::copyBuild(CardLink *card, CardPile * pile)
 	tempCard = removeCard();
 	displayPile();
 	if (card != tempCard)
-		copyBuild(card, pile);
-	pile->addCard(tempCard);
-	pile->displayPile();
+		copyBuild(card, a_pile);
+	a_pile->addCard(tempCard);
+	a_pile->displayPile();
 }
 
 static void stackDisplay(CardLink *p)
@@ -910,7 +916,7 @@ void AlternatePile::displayPile()
 	}
 }
 
-Bool AlternatePile::select(int x, int y)
+Bool AlternatePile::select(int a_x, int a_y)
 {
 	solitarestruct *bp = &solitare[MI_SCREEN(mi)];
 	CardLink *c;
@@ -927,7 +933,7 @@ Bool AlternatePile::select(int x, int y)
 	}
 
 	// if it was to top card, see if we can move it
-	if (top->includes(x, y)) {
+	if (top->includes(a_x, a_y)) {
 		// see if we ca move it to a suit pile
 		if (bp->game->suitCanAdd(top->thisCard())) {
 			copyBuild(top, bp->game->suitAddPile(top->thisCard()));
@@ -943,7 +949,7 @@ Bool AlternatePile::select(int x, int y)
 
 	// else see if we can move a pile
 	for (c = top->nextCard(); c!= nilLink; c = c->nextCard())
-		if (c->isFaceUp() && c->includes(x, y)) {
+		if (c->isFaceUp() && c->includes(a_x, a_y)) {
 			if (bp->game->alternateCanAdd(c->thisCard())) {
 				copyBuild(c, bp->game->alternateAddPile(c->thisCard()));
 			}
@@ -1189,18 +1195,24 @@ extern "C" { void refresh_solitare(ModeInfo * mi); }
 
 static XrmOptionDescRec opts[] =
 {
-	{"-trackmouse", ".solitare.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
-	{"+trackmouse", ".solitare.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
+#ifndef DISABLE_INTERACTIVE
+	{(char *) "-trackmouse", (char *) ".solitare.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+trackmouse", (char *) ".solitare.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
+#endif
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & trackmouse, "trackmouse", "TrackMouse", DEF_TRACKMOUSE, t_Bool}
+#ifndef DISABLE_INTERACTIVE
+	{(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
+#endif
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+trackmouse", "turn on/off the tracking of the mouse"}
+#ifndef DISABLE_INTERACTIVE
+	{(char *) "-/+trackmouse", (char *) "turn on/off the tracking of the mouse"}
+#endif
 };
 
 ModeSpecOpt solitare_opts =
