@@ -1254,10 +1254,10 @@ init_swirl(ModeInfo * mi)
 		int         i;
 
 		/* allocate an array, one entry for each screen */
-		swirls = (SWIRL_P) calloc(ScreenCount(display), sizeof (SWIRL));
+		swirls = (SWIRL_P) calloc(MI_NUM_SCREENS(mi), sizeof (SWIRL));
 
 		/* initialise them all */
-		for (i = 0; i < ScreenCount(display); i++)
+		for (i = 0; i < MI_NUM_SCREENS(mi); i++)
 			initialise_swirl(&swirls[i]);
 	}
 	/* get a pointer to this swirl */
