@@ -68,17 +68,17 @@ static Bool cycle_p;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-cycle", ".tik_tak.cycle", XrmoptionNoArg, (caddr_t) "on"},
-	{"+cycle", ".tik_tak.cycle", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-cycle", (char *) ".tik_tak.cycle", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+cycle", (char *) ".tik_tak.cycle", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & cycle_p, "cycle", "Cycle", DEF_CYCLE, t_Bool}
+	{(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+cycle", "turn on/off colour cycling"}
+	{(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
 };
 
 ModeSpecOpt tik_tak_opts =
@@ -559,7 +559,7 @@ init_tik_tak(ModeInfo * mi)
 		tik_tak_reset_object( object0);
 		tik_tak_drawobject(mi, object0 );
 	}
-	XSync(display, False);
+	XFlush(display);
 	XSetFunction(display, tiktak->gc, GXcopy);
 }
 
