@@ -216,12 +216,10 @@ draw_world(ModeInfo * mi)
 		wp->frame_num = 0;
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		for (i = 0; i < wp->nplanets; i++) {
-			if ((wp->ncols > wp->nplanets || wp->nrows < 2) &&
-			    wp->planets[i].x >= 0 && wp->planets[i].y >= 0)
-				XFillRectangle(display, MI_WINDOW(mi), gc,
-					  wp->xb + SIZE_X * wp->planets[i].x,
-					  wp->yb + SIZE_Y * wp->planets[i].y,
-					       SIZE_X, SIZE_Y);
+			XFillRectangle(display, MI_WINDOW(mi), gc,
+				 wp->xb + SIZE_X * wp->planets[i].x,
+				 wp->yb + SIZE_Y * wp->planets[i].y,
+				 SIZE_X, SIZE_Y);
 #ifdef NOFLASH
 			wp->planets[i].x = NRAND(wp->ncols);
 #else
