@@ -227,7 +227,7 @@ draw_xjack(ModeInfo * mi)
 					jp->y--;
 					lines--;
 #if 0
-					XSync (display, True);
+					XFlush(display);
 					if (delay)
 						 usleep (delay * 10);
 #endif
@@ -307,7 +307,7 @@ draw_xjack(ModeInfo * mi)
 				jp->x--;
 				jp->s--;
 #if 0
-				XSync (display, True);
+				XFlush(display);
 				if (delay)
 					 usleep (0xFFFF & (delay + (NRAND(delay * 10))));
 #endif
@@ -370,7 +370,7 @@ draw_xjack(ModeInfo * mi)
 	}
 
 #if 0
-	XSync (display, True);
+	XFlush(display);
 	if (delay) {
 		usleep (delay);
 		if (!NRAND(3))
@@ -404,7 +404,7 @@ draw_xjack(ModeInfo * mi)
 				n1++;
 			}
 #if 0
-			XSync (display, True);
+			XFlush(display);
 			usleep (5000000);
 #endif
 			while (*n2) {
@@ -419,7 +419,7 @@ draw_xjack(ModeInfo * mi)
 			}
 			jp->y++;
 #if 0
-			XSync (display, True);
+			XFlush(display);
 			usleep (500000);
 #endif
 		}
