@@ -41,9 +41,9 @@ random_lines(Display * dpy, Window window, GC gc,
 	     int width, int height, int delay, int granularity)
 {
 #define ERASEMODE "random_lines"
-	Bool        horiz_p = LRAND() & 1;
+	Bool        horiz_p = (Bool) (LRAND() & 1);
 	int         max = (horiz_p ? height : width);
-	int        *lines = (int *) calloc(max, sizeof (*lines));
+	int        *lines = (int *) calloc(max, sizeof (int));
 	int         i;
         int         actual_delay = delay / max;
 
@@ -88,7 +88,7 @@ random_squares(Display * dpy, Window window, GC gc,
 #define ERASEMODE "random_squares"
 	int         randsize = MAX(1, MIN(width, height) / (16 + NRAND(32)));
 	int         max = (height / randsize + 1) * (width / randsize + 1);
-	int        *squares = (int *) calloc(max, sizeof (*squares));
+	int        *squares = (int *) calloc(max, sizeof (int));
 	int         i;
 	int         columns = width / randsize + 1;  /* Add an extra for roundoff */
         int         actual_delay = delay / max;
@@ -130,10 +130,10 @@ venetian(Display * dpy, Window window, GC gc,
 	 int width, int height, int delay, int granularity)
 {
 #define ERASEMODE "venetian"
-	Bool        horiz_p = LRAND() & 1;
-	Bool        flip_p = LRAND() & 1;
+	Bool        horiz_p = (Bool) (LRAND() & 1);
+	Bool        flip_p = (Bool) (LRAND() & 1);
 	int         max = (horiz_p ? height : width);
-	int        *lines = (int *) calloc(max, sizeof (*lines));
+	int        *lines = (int *) calloc(max, sizeof (int));
 	int         i, j;
         int         actual_delay = delay / max;
 
@@ -174,8 +174,8 @@ triple_wipe(Display * dpy, Window window, GC gc,
 	    int width, int height, int delay, int granularity)
 {
 #define ERASEMODE "triple_wipe"
-	Bool        flip_x = LRAND() & 1;
-	Bool        flip_y = LRAND() & 1;
+	Bool        flip_x = (Bool) (LRAND() & 1);
+	Bool        flip_y = (Bool) (LRAND() & 1);
 	int         max = width + (height / 2);
 	int        *lines = (int *) calloc(max, sizeof (int));
 	int         i;
@@ -224,8 +224,8 @@ quad_wipe(Display * dpy, Window window, GC gc,
 	  int width, int height, int delay, int granularity)
 {
 #define ERASEMODE "quad_wipe"
-	Bool        flip_x = LRAND() & 1;
-	Bool        flip_y = LRAND() & 1;
+	Bool        flip_x = (Bool) (LRAND() & 1);
+	Bool        flip_y = (Bool) (LRAND() & 1);
 	int         max = width + height;
 	int        *lines = (int *) calloc(max, sizeof (int));
 	int         i;
@@ -274,7 +274,7 @@ circle_wipe(Display * dpy, Window window, GC gc,
 {
 #define ERASEMODE "circle_wipe"
 	int         full = 360 * 64;
-	int         inc = full / 64;
+	int         inc = 360;
 	int         start = NRAND(full);
 	int         rad = (width > height ? width : height);
 	int         i;
@@ -365,7 +365,7 @@ granularity));
 
 #endif
 	int         i;
-	Bool        flip = LRAND() & 1;
+	Bool        flip = (Bool) (LRAND() & 1);
         int         actual_delay = delay / steps;
 
 #include "erase_init.h"
@@ -453,21 +453,21 @@ fizzle (Display *dpy, Window window, GC gc,
     }
 
     for( i = 0; i < SIZE; i++ ) {
-      j = LRAND()%(SIZE-i);
+      j = (int) (LRAND() % (SIZE - i));
       array[indices[j]] = i;
-      indices[j] = indices[SIZE-i-1];
+      indices[j] = indices[SIZE - i - 1];
     }
   }
 
   /* nx, ny are the number of cells across and down, rounded up */
-  nx = width  / BX + (0 == (width %BX) ? 0 : 1);
-  ny = height / BY + (0 == (height%BY) ? 0 : 1);
+  nx = width  / BX + (0 == (width % BX) ? 0 : 1);
+  ny = height / BY + (0 == (height % BY) ? 0 : 1);
   skews = (XPoint *)malloc(sizeof(XPoint) * (nx*ny));
   if( (XPoint *)0 != skews ) {
     for( i = 0; i < nx; i++ ) {
       for( j = 0; j < ny; j++ ) {
-        skews[j * nx + i].x = LRAND()%BX;
-        skews[j * nx + i].y = LRAND()%BY;
+        skews[j * nx + i].x = (short) (LRAND() % BX);
+        skews[j * nx + i].y = (short) (LRAND() % BY);
       }
     }
   }
