@@ -184,6 +184,12 @@ LockStruct  LockProcs[] =
 	 10000, 30, 1, 1, 64, 1.0, "",
 	 "Shows cosmic drifting flame fractals", 0, NULL},
 #endif
+#ifdef MODE_euler2d
+	{"euler2d", init_euler2d, draw_euler2d, release_euler2d,
+	 refresh_euler2d, init_euler2d, NULL, &euler2d_opts,
+	 1000, 1024, 3000, 1, 64, 1.0, "",
+	 "Shows a simulation of 2D incompressible inviscid fluid", 0, NULL},
+#endif
 #ifdef MODE_eyes
 	{"eyes", init_eyes, draw_eyes, release_eyes,
 	 refresh_eyes, init_eyes, NULL, &eyes_opts,
@@ -265,7 +271,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_ico
 	{"ico", init_ico, draw_ico, release_ico,
 	 refresh_ico, change_ico, NULL, &ico_opts,
-	 100000, 0, 400, 0, 64, 1.0, "",
+	 200000, 0, 400, 0, 64, 1.0, "",
 	 "Shows a bouncing polyhedron", 0, NULL},
 #endif
 #ifdef MODE_ifs
@@ -289,7 +295,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_juggle
 	{"juggle", init_juggle, draw_juggle, release_juggle,
 	 draw_juggle, init_juggle, NULL, &juggle_opts,
-	 2000, 30, 30, 1, 64, 1.0, "",
+	 10000, 150, 30, 1, 64, 1.0, "",
 	 "Shows a Juggler, juggling", 0, NULL},
 #endif
 #ifdef MODE_julia
@@ -501,6 +507,12 @@ LockStruct  LockProcs[] =
 	 400000, 2000, 100, 1, 64, 1.0, "",
 	 "Shows Sierpinski's triangle", 0, NULL},
 #endif
+#ifdef MODE_skewb
+	{"skewb", init_skewb, draw_skewb, release_skewb,
+	 draw_skewb, change_skewb, NULL, &skewb_opts,
+	 10000, -30, 5, 1, 64, 1.0, "",
+	 "Shows an auto-solving Skewb", 0, NULL},
+#endif
 #ifdef MODE_slip
 	{"slip", init_slip, draw_slip, release_slip,
 	 init_slip, init_slip, NULL, &slip_opts,
@@ -576,7 +588,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_swarm
 	{"swarm", init_swarm, draw_swarm, release_swarm,
 	 refresh_swarm, init_swarm, NULL, &swarm_opts,
-	 15000, 100, 1, 1, 64, 1.0, "",
+	 15000, -100, 1, -100, 64, 1.0, "",
 	 "Shows a swarm of bees following a wasp", 0, NULL},
 #endif
 #ifdef MODE_swirl
@@ -593,7 +605,7 @@ LockStruct  LockProcs[] =
 #endif
 #ifdef MODE_tetris
 	{"tetris", init_tetris, draw_tetris, release_tetris,
-	 refresh_tetris, init_tetris, NULL, &tetris_opts,
+	 refresh_tetris, change_tetris, NULL, &tetris_opts,
 	 50000, 1, 1, 0, 64, 1.0, "",
 	 "Shows an autoplaying tetris game", 0, NULL},
 #endif
@@ -669,6 +681,12 @@ LockStruct  LockProcs[] =
 	 17000, -20, 10, -3, 64, 1.0, "",
 	 "Shows wiggly worms", 0, NULL},
 #endif
+#ifdef MODE_xcl
+	{"xcl", init_xcl, draw_xcl, release_xcl,
+	 refresh_xcl, init_xcl, NULL, &xcl_opts,
+	 20000, -3, 1, 1, 64, 1.0, "",
+	 "Shows a control line combat model race", 0, NULL},
+#endif
 #ifdef MODE_xjack
 	{"xjack", init_xjack, draw_xjack, release_xjack,
 	 init_xjack, init_xjack, NULL, &xjack_opts,
@@ -681,6 +699,12 @@ LockStruct  LockProcs[] =
 	 refresh_blank, init_blank, NULL, &blank_opts,
 	 3000000, 1, 1, 1, 64, 1.0, "",
 	 "Shows nothing but a black screen", 0, NULL},
+#ifdef MODE_run
+	{"run", init_run, draw_run, release_run,
+	 refresh_run, init_run, NULL, &run_opts,
+	 3000000, 1, 1, 1, 64, 1.0, "",
+	 "Shows another xprogram", 0, NULL},
+#endif
 #ifdef MODE_bomb
 	{"bomb", init_bomb, draw_bomb, release_bomb,
 	 refresh_bomb, change_bomb, NULL, &bomb_opts,
@@ -1039,17 +1063,18 @@ static void
 set_window_title(ModeInfo * mi)
 {
 	XTextProperty prop;
-	char        buf[512];
-	char       *ptr = buf;
+	char       *buf;
 	unsigned int status;
 	extern Bool description;
 
+	buf = (char *) malloc(strlen(MI_NAME(mi)) + strlen(MI_DESC(mi)) + 3);
 	(void) sprintf(buf, "%s: %s", MI_NAME(mi), MI_DESC(mi));
-	status = XStringListToTextProperty(&ptr, 1, &prop);
+	status = XStringListToTextProperty(&buf, 1, &prop);
 	if (status != 0) {
 		XSetWMName(MI_DISPLAY(mi), MI_WINDOW(mi), &prop);
 		XFree((caddr_t) prop.value);
 	}
+	(void) free((void *) buf);
 	if (MI_IS_ICONIC(mi) && description) {
 		modeDescription(mi);
 	}
