@@ -155,16 +155,6 @@ XrmOptionDescRec options[100];
 #endif
 #include <math.h>
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#ifdef USE_MB
-#ifdef __linux__
-#define X_LOCALE
-#endif
-#include <X11/Xlocale.h>
-#endif
-#else /* HAVE_CONFIG_H */
-
 /* I use this for testing SunCplusplus
    I still get this in the link:
    Undefined                       first referenced
@@ -173,9 +163,25 @@ XrmOptionDescRec options[100];
    kill(long, int)                         ../xlock/logout.o
    signal(int, void (*)(int))                   ../xlock/logout.o
 
-   #define SUN_OGL_NO_VERTEX_MACROS 1
-   #define SunCplusplus
  */
+#ifdef SunCplusplus
+#ifndef HAVE_USLEEP
+#define HAVE_USLEEP 1
+#endif
+#ifndef SUN_OGL_NO_VERTEX_MACROS
+#define SUN_OGL_NO_VERTEX_MACROS 1
+#endif
+#endif
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#ifdef USE_MB
+#ifdef __linux__
+/*#define X_LOCALE*/
+#endif
+#include <X11/Xlocale.h>
+#endif
+#else /* HAVE_CONFIG_H */
 
 /* THIS MAY SOON BE DEFUNCT, SHOULD WORK NOW THOUGH FOR IMAKE */
 #define HAVE_GLBINDTEXTURE 1
@@ -233,6 +239,13 @@ XrmOptionDescRec options[100];
 #endif
 #define PASSLENGTH        120
 
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
+#ifndef MAXPATHLEN
+#define MAXPATHLEN 1024
+#endif
+
 #ifndef DEF_NONE3D
 #define DEF_NONE3D "Black"
 #endif
@@ -320,6 +333,9 @@ XrmOptionDescRec options[100];
 #ifndef size_t
 #define size_t unsigned
 #endif
+#ifndef caddr_t
+#define caddr_t char *
+#endif
 #endif
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -471,7 +487,11 @@ typedef struct {
 extern char * ProgramName;
 extern void getResources(Display ** displayp, int argc, char **argv);
 extern void finish(Display * display, Bool closeDisplay);
+#ifdef HAS_MMOV
+#define error xlock_error
+#endif
 extern void error(const char *buf);
+extern char * getenv(const char *);
 #ifdef __cplusplus
   }
 #endif
@@ -497,7 +517,8 @@ extern void error(const char *buf);
 #define SYSLOG_INFO LOG_INFO
 #endif
 
-#if (defined( USE_RPLAY ) || defined( USE_NAS ) || defined( USE_VMSPLAY ) || defined( DEF_PLAY ) || defined( USE_ESOUND ))
+#if (defined( USE_RPLAY ) || defined( USE_NAS ) || defined( USE_VMSPLAY ) || \
+     defined( HAS_MMOV ) || defined( DEF_PLAY ) || defined( USE_ESOUND ))
 #define USE_SOUND
 #endif
 
@@ -529,6 +550,7 @@ extern XFontSet fontset;
 #endif
 #endif
 
+
 /* There is some overlap so it can be made more efficient */
 #define ERASE_IMAGE(d,w,g,x,y,xl,yl,xs,ys) \
 if (yl<y) \
