@@ -40,6 +40,7 @@ static LockStruct LockProcs[] =
 {"dilemma","Shows Lloyd's Prisoner's Dilemma simulation"},
 {"discrete","Shows various discrete maps"},
 {"drift","Shows cosmic drifting flame fractals"},
+{"euler2d","Shows a simulation of 2D incompressible inviscid fluid"},
 {"eyes","Shows eyes following a bouncing grelb"},
 {"fadeplot","Shows a fading plot of sine squared"},
 {"flag","Shows a waving flag image"},
@@ -106,6 +107,9 @@ static LockStruct LockProcs[] =
 #endif
 {"shape","Shows stippled rectangles, ellipses, and triangles"},
 {"sierpinski","Shows Sierpinski's triangle"},
+#if defined(USE_GL) && defined( USE_UNSTABLE )
+{"skewb","Shows an auto-solving Skewb"},
+#endif
 {"slip","Shows slipping blits"},
 #ifdef HAVE_CXX
 {"solitare","Shows Klondike's game of solitare"},
@@ -143,6 +147,7 @@ static LockStruct LockProcs[] =
 {"wire","Shows a random circuit with 2 electrons"},
 {"world","Shows spinning Earths"},
 {"worm","Shows wiggly worms"},
+{"xcl","Shows a control line combat model race"},
 {"xjack","Shows Jack having one of those days"},
 {"blank","Shows nothing but a black screen"},
 #ifdef USE_BOMB
