@@ -42,6 +42,10 @@ static const char sccsid[] = "@(#)xmlock.c	4.08 98/02/18 xlockmore";
 #include <lib$routines.h>
 #endif
 
+#ifdef USE_MB
+#include <X11/Xlocale.h>
+#endif
+
 /* #include <Xm/XmAll.h> Does not work on my version of Lesstif */
 #include <Xm/PanedW.h>
 #include <Xm/RowColumn.h>
@@ -55,6 +59,18 @@ static const char sccsid[] = "@(#)xmlock.c	4.08 98/02/18 xlockmore";
 #include <X11/Xmu/Editres.h>
 #endif
 
+#ifdef SunCplusplus
+        extern int  kill(long, int);
+        extern pid_t  wait(int *);
+
+#else
+#if 0
+        extern int  kill(int, int);
+        extern pid_t  wait(int *);
+
+#endif
+#endif
+
 #include "bitmaps/m-xlock.xbm"	/* icon bitmap */
 
 /* like an enum */
@@ -230,9 +246,7 @@ Setup_Widget(Widget father)
 	Widget      Row, PushButtonRow, TogglesRow, ModeLabel, SwitchLabel;
 	char        string[160];
 	XmString    label_str;
-
-#define NUMPROCS 100		/* Greater than or equal to numprocs */
-	XmString    TabXmStr[NUMPROCS];
+	XmString    TabXmStr[numprocs];
 
 	ac = 0;
 	XtSetArg(args[ac], XmNrightAttachment, XmATTACH_FORM);
@@ -283,12 +297,16 @@ Setup_Widget(Widget father)
 
 	for (i = 0; i < PUSHBUTTONS; i++) {
 		ac = 0;
+#ifndef USE_MB
 		label_str = XmStringCreate(r_PushButtons[i], XmSTRING_DEFAULT_CHARSET);
 		XtSetArg(args[ac], XmNlabelString, label_str);
 		ac++;
+#endif
 		PushButtons[i] = XmCreatePushButton(PushButtonRow, r_PushButtons[i],
 						    args, ac);
+#ifndef USE_MB
 		XmStringFree(label_str);
+#endif
 		XtAddCallback(PushButtons[i], XmNactivateCallback, f_PushButtons,
 			      (XtPointer) i);
 		XtManageChild(PushButtons[i]);
@@ -313,9 +331,6 @@ Setup_Widget(Widget father)
 	ac++;
 	Row = XmCreateRowColumn(father, "Row", args, ac);
 
-	if (numprocs > NUMPROCS) {
-		(void) printf("NUMPROCS too small should be at least %d\n", numprocs);
-	}
 	for (i = 0; i < numprocs; i++) {
 		(void) sprintf(string, "%-14s%s", LockProcs[i].cmdline_arg,
 			       LockProcs[i].desc);
@@ -336,12 +351,16 @@ Setup_Widget(Widget father)
 
 	TogglesRow = XmCreateRowColumn(Row, "TogglesRow", NULL, 0);
 	for (i = 0; i < TOGGLES; i++) {
+#ifndef USE_MB
 		ac = 0;
 		label_str = XmStringCreate(r_Toggles[i], XmSTRING_DEFAULT_CHARSET);
 		XtSetArg(args[ac], XmNlabelString, label_str);
 		ac++;
+#endif
 		Toggles[i] = XmCreateToggleButton(TogglesRow, r_Toggles[i], args, ac);
+#ifndef USE_MB
 		XmStringFree(label_str);
+#endif
 		XtManageChild(Toggles[i]);
 	}
 	XtManageChild(TogglesRow);
@@ -358,6 +377,11 @@ main(int argc, char **argv)
 	Widget      form;
 	Arg         args[15];
 
+#ifdef USE_MB
+	setlocale(LC_ALL, "");
+	XtSetLanguageProc(NULL, NULL, NULL);
+#endif
+
 /* PURIFY 4.0.1 on Solaris 2 reports an unitialized memory read on the next
    line. */
 	toplevel = XtInitialize(argv[0], "XmLock", NULL, 0, &argc, argv);
